"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const react_1 = __importDefault(require("react"));
const actions_1 = require("../actions");
// helpers
function normalizeHref(href) {
    return href ? href.replace(/^\//, '') : '';
}
function isModifiedEvent(event) {
    return !!(event.metaKey || event.altKey || event.ctrlKey || event.shiftKey);
}
exports.RouterContext = react_1.default.createContext({});
exports.dispatchProps = {
    onNavigate: (href, options) => actions_1.callHistoryMethod(href, options)
};
class BaseLinkComponent extends react_1.default.Component {
    constructor() {
        super(...arguments);
        this.handleClick = (event) => {
            const { target, onClick, onNavigate, replace, state } = this.props;
            if (onClick) {
                onClick(event);
            }
            if (!event.defaultPrevented && // onClick prevented default
                event.button === 0 && // ignore everything but left clicks
                (!target || target === '_self') && // let browser handle "target=_blank" etc.
                !isModifiedEvent(event) // ignore clicks with modifier keys
            ) {
                event.preventDefault();
                onNavigate(this.getHref(), { replace, state }); // todo: memo
            }
        };
    }
    getRenderHref() {
        const href = normalizeHref(this.getHref());
        const basename = normalizeHref(this.context.basename);
        return basename ? `/${basename}/${href}` : `/${href}`;
    }
    render() {
        const { attrs, children, className, target, dangerouslySetInnerHTML } = this.props;
        const href = this.getRenderHref();
        const props = Object.assign({}, attrs, { href, className, target });
        dangerouslySetInnerHTML && (props.dangerouslySetInnerHTML = dangerouslySetInnerHTML);
        return (react_1.default.createElement("a", Object.assign({}, props, { onClick: this.handleClick }), children));
    }
}
BaseLinkComponent.contextType = exports.RouterContext;
exports.BaseLinkComponent = BaseLinkComponent;
